@@ -22,10 +22,9 @@
 #include <QThread>
 #include <QUrlQuery>
 
+#include "kconfig_version.h"
 #include <KAboutData>
 #include <KColorSchemeManager>
-#include <KConfig>
-#include <KConfigGroup>
 #include <KCrash>
 #include <KFileItem>
 #include <KFileMetaData/Properties>
@@ -71,15 +70,24 @@ Application *Application::create(QQmlEngine *, QJSEngine *)
     return instance();
 }
 
+bool Application::actionsEnabled()
+{
+    return m_actionsEnabled;
+}
+
+void Application::setActionsEnabled(bool enable)
+{
+    if (enable == actionsEnabled()) {
+        return;
+    }
+    m_actionsEnabled = enable;
+    Q_EMIT actionsEnabledChanged();
+}
+
 Application::Application()
     : QObject{nullptr}
     , m_app(qApp)
-    , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath()))
-#if KCOLORSCHEME_VERSION < QT_VERSION_CHECK(6, 6, 0)
-    , m_schemes(new KColorSchemeManager(this))
-#else
     , m_schemes(KColorSchemeManager::instance())
-#endif
     , m_systemDefaultStyle(m_app->style()->objectName())
     , m_appEventFilter{std::make_unique<ApplicationEventFilter>()}
 {
