@@ -12,7 +12,6 @@
 #include <QQmlPropertyMap>
 
 #include <KAboutData>
-#include <KSharedConfig>
 
 class QAbstractItemModel;
 class QApplication;
@@ -45,6 +44,9 @@ public:
 
     Q_PROPERTY(QAbstractItemModel *colorSchemesModel READ colorSchemesModel CONSTANT)
     Q_PROPERTY(QQmlPropertyMap *actions MEMBER m_actions CONSTANT)
+    Q_PROPERTY(bool actionsEnabled READ actionsEnabled WRITE setActionsEnabled NOTIFY actionsEnabledChanged)
+    bool actionsEnabled();
+    void setActionsEnabled(bool enable);
 
     Q_INVOKABLE bool urlExists(const QUrl &url);
     Q_INVOKABLE bool pathExists(const QString &url);
@@ -82,6 +84,7 @@ Q_SIGNALS:
     void qmlApplicationMouseEnter();
     void error(const QString &message);
     void openUrl(const QUrl &url);
+    void actionsEnabledChanged();
 
 private:
     explicit Application();
@@ -99,7 +102,6 @@ private:
     QAbstractItemModel *colorSchemesModel();
     QApplication *m_app{nullptr};
     KAboutData m_aboutData;
-    KSharedConfig::Ptr m_config;
     std::unique_ptr<QCommandLineParser> m_parser;
     QMap<int, QUrl> m_urls;
     KColorSchemeManager *m_schemes{nullptr};
@@ -107,6 +109,7 @@ private:
     QQmlApplicationEngine *m_qmlEngine{nullptr};
     std::unique_ptr<ApplicationEventFilter> m_appEventFilter;
     QQmlPropertyMap *m_actions{new QQmlPropertyMap};
+    bool m_actionsEnabled{true};
 };
 
 #endif // APPLICATION_H
