@@ -18,6 +18,7 @@
 #include "application.h"
 #include "mpvitem.h"
 #include "mpvproperties.h"
+#include "playlistsettings.h"
 #include "videosettings.h"
 #include "worker.h"
 
@@ -29,7 +30,10 @@ MediaPlayer2Player::MediaPlayer2Player(QObject *parent)
 {
     connect(m_mpv, &MpvItem::fileLoaded, this, [=]() {
         if (m_mpv->currentUrl().isLocalFile()) {
-            Q_EMIT requestMprisThumbnail(m_mpv->currentUrl().toLocalFile(), 250);
+            QString mimeType = Application::mimeType(m_mpv->currentUrl());
+            if (mimeType.startsWith(u"audio"_s)) {
+                Q_EMIT requestMprisThumbnail(m_mpv->currentUrl().toLocalFile(), 250);
+            }
         }
     });
 
@@ -65,6 +69,13 @@ MediaPlayer2Player::MediaPlayer2Player(QObject *parent)
         propertiesChanged(u"Volume"_s, Volume());
         Q_EMIT volumeChanged();
     });
+
+    connect(PlaylistSettings::self(), &PlaylistSettings::PlaybackBehaviorChanged, this, [=]() {
+        propertiesChanged(u"LoopStatus"_s, LoopStatus());
+    });
+    connect(PlaylistSettings::self(), &PlaylistSettings::RandomPlaybackChanged, this, [=]() {
+        propertiesChanged(u"Shuffle"_s, Shuffle());
+    });
 }
 
 void MediaPlayer2Player::propertiesChanged(const QString &property, const QVariant &value)
@@ -81,10 +92,15 @@ void MediaPlayer2Player::propertiesChanged(const QString &property, const QVaria
 QVariantMap MediaPlayer2Player::Metadata()
 {
     auto url = m_mpv->currentUrl();
+    QString mimeType = Application::mimeType(url);
 
     m_metadata.insert(u"xesam:title"_s, m_mpv->mediaTitle());
     m_metadata.insert(u"mpris:trackid"_s, QVariant::fromValue<QDBusObjectPath>(QDBusObjectPath(u"/org/kde/haruna"_s)));
-    m_metadata.insert(u"mpris:artUrl"_s, getThumbnail(url.toLocalFile()));
+    if (mimeType.startsWith(u"audio"_s)) {
+        m_metadata.insert(u"mpris:artUrl"_s, getThumbnail(url.toLocalFile()));
+    } else {
+        m_metadata.insert(u"mpris:artUrl"_s, QString{});
+    }
     m_metadata.insert(u"xesam:url"_s, url.toString());
 
     return m_metadata;
@@ -200,6 +216,28 @@ void MediaPlayer2Player::setVolume(double vol)
     Q_EMIT m_mpv->setProperty(MpvProperties::self()->Volume, vol * 100);
 }
 
+void MediaPlayer2Player::setShuffle(bool shuffle)
+{
+    PlaylistSettings::setRandomPlayback(shuffle);
+    PlaylistSettings::self()->save();
+    Q_EMIT PlaylistSettings::self()->RandomPlaybackChanged();
+}
+
+void MediaPlayer2Player::setLoopStatus(QString loop)
+{
+    if (loop == u"None"_s) {
+        loop = u"StopAfterLast"_s;
+    } else if (loop == u"Track"_s) {
+        loop = u"RepeatItem"_s;
+    } else if (loop == u"Playlist"_s) {
+        loop = u"RepeatPlaylist"_s;
+    }
+
+    PlaylistSettings::setPlaybackBehavior(loop);
+    PlaylistSettings::self()->save();
+    Q_EMIT PlaylistSettings::self()->PlaybackBehaviorChanged();
+}
+
 qlonglong MediaPlayer2Player::Position()
 {
     return m_mpv->position() * 1000 * 1000;
@@ -240,4 +278,21 @@ bool MediaPlayer2Player::CanControl()
     return true;
 }
 
+bool MediaPlayer2Player::Shuffle()
+{
+    return PlaylistSettings::randomPlayback();
+}
+
+QString MediaPlayer2Player::LoopStatus()
+{
+    if (PlaylistSettings::playbackBehavior() == u"RepeatItem"_s) {
+        return u"Track"_s;
+    }
+    if (PlaylistSettings::playbackBehavior() == u"RepeatPlaylist"_s) {
+        return u"Playlist"_s;
+    }
+    // StopAfterLast or StopAfterItem
+    return u"None"_s;
+}
+
 #include "moc_mediaplayer2player.cpp"
