@@ -28,7 +28,7 @@ public:
         return &p;
     }
 
-    Q_PROPERTY(QString VO MEMBER Pause CONSTANT)
+    Q_PROPERTY(QString VO MEMBER VO CONSTANT)
     const QString VO{u"vo"_s};
 
     Q_PROPERTY(QString Pause MEMBER Pause CONSTANT)
@@ -220,6 +220,12 @@ public:
     Q_PROPERTY(QString TracksCount MEMBER TracksCount CONSTANT)
     const QString TracksCount{u"track-list/count"_s};
 
+    Q_PROPERTY(QString KeepOpen MEMBER KeepOpen CONSTANT)
+    const QString KeepOpen{u"keep-open"_s};
+
+    Q_PROPERTY(QString EofReached MEMBER EofReached CONSTANT)
+    const QString EofReached{u"eof-reached"_s};
+
 private:
     Q_DISABLE_COPY_MOVE(MpvProperties)
 };
