@@ -7,15 +7,15 @@
 #ifndef WORKER_H
 #define WORKER_H
 
-#include <QImage>
 #include <QObject>
+#include <QSqlDatabase>
 
 #include <KFileMetaData/Properties>
-#include <kconfig_version.h>
 
 #include <memory>
 
 class KConfig;
+class QImage;
 class QQuickWindow;
 
 class Worker : public QObject
@@ -25,19 +25,21 @@ public:
     static Worker *instance();
 
 Q_SIGNALS:
-    void metaDataReady(uint index, const QUrl &url, KFileMetaData::PropertyMultiMap metadata);
+    void metaDataReady(uint index, const QUrl &url, const QString playlistName, KFileMetaData::PropertyMultiMap metadata);
     void thumbnailSuccess(const QString &path, const QImage &image);
     void thumbnailFail();
     void mprisThumbnailSuccess(const QImage &image);
     void subtitlesFound(QStringList subs);
+    void ytdlpVersionRetrived(const QByteArray &version);
 
 public Q_SLOTS:
-    void getMetaData(uint index, const QString &path);
+    void getMetaData(uint index, const QString &path, const QString playlistName);
     void makePlaylistThumbnail(const QString &path, int width);
     QImage frameToImage(const QString &path, int width);
-    void syncConfigValue(QString path, QString group, QString key, QVariant value);
+    void savePositionToDB(const QString &md5Hash, const QString &path, double position);
     void mprisThumbnail(const QString &path, int width);
-    void findRecursiveSubtitles(const QUrl &url);
+    void findRecursiveSubtitles(const QUrl &playingUrl);
+    void getYtdlpVersion();
 
 private:
     Worker() = default;
@@ -48,8 +50,7 @@ private:
     Worker(Worker &&) = delete;
     Worker &operator=(Worker &&) = delete;
 
-private:
-    std::unique_ptr<KConfig> m_cachedConf;
+    QSqlDatabase getDBConnection();
 };
 
 #endif // WORKER_H
